@@ -1,9 +1,10 @@
 pub use client::UdpClient;
 pub use pusher::UdpPusher;
 pub use server::UdpServer;
+pub use server::UdpServerAsync;
 pub use socket::Socket;
-
 mod client;
+pub mod error;
 mod pusher;
 mod server;
 mod socket;
